@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2004-2010 Open Source Applications Foundation.
+ * Copyright (c) 2004-2011 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -116,6 +116,8 @@ DECLARE_TYPE(Collator, t_collator, UObject, Collator, abstract_init, NULL);
 class t_rulebasedcollator : public _wrapper {
 public:
     RuleBasedCollator *object;
+    PyObject *buf;
+    PyObject *base;
 };
 
 static int t_rulebasedcollator_init(t_rulebasedcollator *self,
@@ -123,15 +125,30 @@ static int t_rulebasedcollator_init(t_rulebasedcollator *self,
 static PyObject *t_rulebasedcollator_getRules(t_rulebasedcollator *self,
                                               PyObject *args);
 static PyObject *t_rulebasedcollator_createCollationElementIterator(t_rulebasedcollator *self, PyObject *arg);
+static PyObject *t_rulebasedcollator_cloneBinary(t_rulebasedcollator *self);
 
 static PyMethodDef t_rulebasedcollator_methods[] = {
     DECLARE_METHOD(t_rulebasedcollator, getRules, METH_VARARGS),
     DECLARE_METHOD(t_rulebasedcollator, createCollationElementIterator, METH_O),
+    DECLARE_METHOD(t_rulebasedcollator, cloneBinary, METH_NOARGS),
     { NULL, NULL, 0, NULL }
 };
 
+static void t_rulebasedcollator_dealloc(t_rulebasedcollator *self)
+{
+    if (self->flags & T_OWNED)
+        delete self->object;
+    self->object = NULL;
+
+    Py_CLEAR(self->buf);
+    Py_CLEAR(self->base);
+
+    Py_TYPE(self)->tp_free((PyObject *) self);
+}
+
 DECLARE_TYPE(RuleBasedCollator, t_rulebasedcollator, Collator,
-             RuleBasedCollator, t_rulebasedcollator_init, NULL);
+             RuleBasedCollator, t_rulebasedcollator_init,
+             t_rulebasedcollator_dealloc);
 
 
 /* CollationKey */
@@ -180,10 +197,10 @@ static PyObject *t_collationkey_getByteArray(t_collationkey *self)
     int32_t count;
     const uint8_t *array = self->object->getByteArray(count);
 
-    return PyString_FromStringAndSize((char *) array, count);
+    return PyBytes_FromStringAndSize((char *) array, count);
 }
 
-DECLARE_RICHCMP(CollationKey, t_collationkey);
+DEFINE_RICHCMP(CollationKey, t_collationkey);
 
 
 /* Collator */
@@ -292,7 +309,7 @@ static PyObject *t_collator_getSortKey(t_collator *self, PyObject *args)
 {
     UnicodeString *u;
     UnicodeString _u;
-    uint32_t len;
+    uint32_t len, size;
     uint8_t *buf;
     PyObject *key;
 
@@ -300,14 +317,24 @@ static PyObject *t_collator_getSortKey(t_collator *self, PyObject *args)
       case 1:
         if (!parseArgs(args, "S", &u, &_u))
         {
-            len = u->length() * 4;
-            buf = (uint8_t *) calloc(len, 1);
+            len = u->length() * 4 + 8;
+            buf = (uint8_t *) malloc(len);
+          retry:
             if (buf == NULL)
                 return PyErr_NoMemory();
 
-            len = self->object->getSortKey(*u, buf, len);
-            key = PyString_FromStringAndSize((char *) buf, len);
-            free(buf);
+            size = self->object->getSortKey(*u, buf, len);
+            if (size <= len)
+            {
+                key = PyBytes_FromStringAndSize((char *) buf, size);
+                free(buf);
+            }
+            else
+            {
+                len = size;
+                buf = (uint8_t *) realloc(buf, len);
+                goto retry;
+            }
 
             return key;
         }
@@ -320,7 +347,7 @@ static PyObject *t_collator_getSortKey(t_collator *self, PyObject *args)
                 return PyErr_NoMemory();
 
             len = self->object->getSortKey(*u, buf, len);
-            key = PyString_FromStringAndSize((char *) buf, len);
+            key = PyBytes_FromStringAndSize((char *) buf, len);
             free(buf);
 
             return key;
@@ -371,6 +398,12 @@ static PyObject *t_collator_getLocale(t_collator *self, PyObject *args)
     return PyErr_SetArgsError((PyObject *) self, "getLocale", args);
 }
 
+static inline PyObject *wrap_Collator(Collator *collator)
+{
+    RETURN_WRAPPED_IF_ISINSTANCE(collator, RuleBasedCollator);
+    return wrap_Collator(collator, T_OWNED);
+}
+
 static PyObject *t_collator_createInstance(PyTypeObject *type, PyObject *args)
 {
     Locale *locale;
@@ -379,12 +412,12 @@ static PyObject *t_collator_createInstance(PyTypeObject *type, PyObject *args)
     switch (PyTuple_Size(args)) {
       case 0:
         STATUS_CALL(collator = Collator::createInstance(status));
-        return wrap_Collator(collator, T_OWNED);
+        return wrap_Collator(collator);
       case 1:
         if (!parseArgs(args, "P", TYPE_CLASSID(Locale), &locale))
         {
             STATUS_CALL(collator = Collator::createInstance(*locale, status));
-            return wrap_Collator(collator, T_OWNED);
+            return wrap_Collator(collator);
         }
         break;
     }
@@ -403,9 +436,9 @@ static PyObject *t_collator_getKeywords(PyTypeObject *type)
 static PyObject *t_collator_getKeywordValues(PyTypeObject *type, PyObject *arg)
 {
     StringEnumeration *e;
-    char *keyword;
+    charsArg keyword;
 
-    if (!parseArg(arg, "c", &keyword))
+    if (!parseArg(arg, "n", &keyword))
     {
         STATUS_CALL(e = Collator::getKeywordValues(keyword, status));
         return wrap_StringEnumeration(e, T_OWNED);
@@ -435,9 +468,9 @@ static PyObject *t_collator_getFunctionalEquivalent(PyTypeObject *type,
 {
     UBool isAvailable;
     Locale *locale;
-    char *keyword;
+    charsArg keyword;
     
-    if (!parseArgs(args, "cP", TYPE_CLASSID(Locale),
+    if (!parseArgs(args, "nP", TYPE_CLASSID(Locale),
                    &keyword, &locale))
     {
         Locale result(*locale);
@@ -531,6 +564,7 @@ static int t_rulebasedcollator_init(t_rulebasedcollator *self,
     RuleBasedCollator *collator;
     Collator::ECollationStrength strength;
     UColAttributeValue decompositionMode;
+    PyObject *buf, *base;
 
     switch (PyTuple_Size(args)) {
       case 1:
@@ -544,7 +578,15 @@ static int t_rulebasedcollator_init(t_rulebasedcollator *self,
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
       case 2:
-        /* two-parameter case is ambiguous from python with ints */
+        if (!parseArgs(args, "CO", &RuleBasedCollatorType, &buf, &base))
+        {
+            INT_STATUS_CALL(collator = new RuleBasedCollator((uint8_t *) PyBytes_AS_STRING(buf), PyBytes_GET_SIZE(buf), ((t_rulebasedcollator *) base)->object, status));
+            self->object = collator;
+            self->flags = T_OWNED;
+            self->buf = buf; Py_INCREF(buf);
+            self->base = base; Py_INCREF(base);
+            break;
+        }
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
       case 3:
@@ -595,13 +637,29 @@ static PyObject *t_rulebasedcollator_createCollationElementIterator(t_rulebasedc
     return PyErr_SetArgsError((PyObject *) self, "createCollationElementIterator", arg);
 }
 
+static PyObject *t_rulebasedcollator_cloneBinary(t_rulebasedcollator *self)
+{
+    UErrorCode status = U_ZERO_ERROR;
+    PyObject *result;
+    int32_t len;
+
+    len = self->object->cloneBinary(NULL, 0, status);
+    result = PyBytes_FromStringAndSize(NULL, len);
+    if (!result)
+        return NULL;
+
+    STATUS_CALL(len = self->object->cloneBinary((uint8_t *) PyBytes_AS_STRING(result), len, status));
+
+    return result;
+}
+
 static PyObject *t_rulebasedcollator_str(t_rulebasedcollator *self)
 {
     UnicodeString u = self->object->getRules();
     return PyUnicode_FromUnicodeString(&u);
 }
 
-DECLARE_RICHCMP(RuleBasedCollator, t_rulebasedcollator);
+DEFINE_RICHCMP(RuleBasedCollator, t_rulebasedcollator);
 
 
 void _init_collator(PyObject *m)
