@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2004-2010 Open Source Applications Foundation.
+ * Copyright (c) 2004-2011 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -140,7 +140,7 @@ static void t_ucharcharacteriterator_dealloc(t_ucharcharacteriterator *self)
     self->object = NULL;
 
     Py_CLEAR(self->text);
-    self->ob_type->tp_free((PyObject *) self);
+    Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
 DECLARE_TYPE(UCharCharacterIterator, t_ucharcharacteriterator,
@@ -238,7 +238,7 @@ static void t_breakiterator_dealloc(t_breakiterator *self)
 
     Py_CLEAR(self->text);
 
-    self->ob_type->tp_free((PyObject *) self);
+    Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
 DECLARE_TYPE(BreakIterator, t_breakiterator, UObject, BreakIterator,
@@ -834,6 +834,22 @@ static PyObject *t_breakiterator_getLocaleID(t_breakiterator *self,
     return PyErr_SetArgsError((PyObject *) self, "getLocaleID", args);
 }
 
+static inline PyObject *wrap_BreakIterator(BreakIterator *iterator)
+{
+#if U_ICU_VERSION_HEX < 0x04060000
+    if (iterator->getDynamicClassID() ==
+        RuleBasedBreakIterator::getStaticClassID())
+        return wrap_RuleBasedBreakIterator(
+            (RuleBasedBreakIterator *) iterator, T_OWNED);
+#else
+    if (dynamic_cast<RuleBasedBreakIterator *>(iterator) != NULL)
+        return wrap_RuleBasedBreakIterator(
+            (RuleBasedBreakIterator *) iterator, T_OWNED);
+#endif
+
+    return wrap_BreakIterator(iterator, T_OWNED);
+}
+
 static PyObject *t_breakiterator_createWordInstance(PyTypeObject *type,
                                                     PyObject *arg)
 {
@@ -843,7 +859,7 @@ static PyObject *t_breakiterator_createWordInstance(PyTypeObject *type,
     if (!parseArg(arg, "P", TYPE_CLASSID(Locale), &locale))
     {
         STATUS_CALL(iterator = BreakIterator::createWordInstance(*locale, status));
-        return wrap_BreakIterator(iterator, T_OWNED);
+        return wrap_BreakIterator(iterator);
     }
 
     return PyErr_SetArgsError(type, "createWordInstance", arg);
@@ -858,7 +874,7 @@ static PyObject *t_breakiterator_createLineInstance(PyTypeObject *type,
     if (!parseArg(arg, "P", TYPE_CLASSID(Locale), &locale))
     {
         STATUS_CALL(iterator = BreakIterator::createLineInstance(*locale, status));
-        return wrap_BreakIterator(iterator, T_OWNED);
+        return wrap_BreakIterator(iterator);
     }
 
     return PyErr_SetArgsError(type, "createLineInstance", arg);
@@ -873,7 +889,7 @@ static PyObject *t_breakiterator_createCharacterInstance(PyTypeObject *type,
     if (!parseArg(arg, "P", TYPE_CLASSID(Locale), &locale))
     {
         STATUS_CALL(iterator = BreakIterator::createCharacterInstance(*locale, status));
-        return wrap_BreakIterator(iterator, T_OWNED);
+        return wrap_BreakIterator(iterator);
     }
 
     return PyErr_SetArgsError(type, "createCharacterInstance", arg);
@@ -888,7 +904,7 @@ static PyObject *t_breakiterator_createSentenceInstance(PyTypeObject *type,
     if (!parseArg(arg, "P", TYPE_CLASSID(Locale), &locale))
     {
         STATUS_CALL(iterator = BreakIterator::createSentenceInstance(*locale, status));
-        return wrap_BreakIterator(iterator, T_OWNED);
+        return wrap_BreakIterator(iterator);
     }
 
     return PyErr_SetArgsError(type, "createSentenceInstance", arg);
@@ -903,7 +919,7 @@ static PyObject *t_breakiterator_createTitleInstance(PyTypeObject *type,
     if (!parseArg(arg, "P", TYPE_CLASSID(Locale), &locale))
     {
         STATUS_CALL(iterator = BreakIterator::createTitleInstance(*locale, status));
-        return wrap_BreakIterator(iterator, T_OWNED);
+        return wrap_BreakIterator(iterator);
     }
 
     return PyErr_SetArgsError(type, "createTitleInstance", arg);
@@ -1029,7 +1045,7 @@ static int t_rulebasedbreakiterator_init(t_rulebasedbreakiterator *self,
                                          PyObject *args, PyObject *kwds)
 {
     UnicodeString *u, _u;
-    char *path, *name;
+    charsArg path, name;
 
     switch (PyTuple_Size(args)) {
       case 0:
@@ -1049,7 +1065,7 @@ static int t_rulebasedbreakiterator_init(t_rulebasedbreakiterator *self,
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
       case 2:
-        if (!parseArg(args, "cc", &path, &name))
+        if (!parseArg(args, "fn", &path, &name))
         {
             RuleBasedBreakIterator *iterator;
             UDataMemory *data;
@@ -1386,7 +1402,7 @@ static PyObject *t_collationelementiterator_iter_next(t_collationelementiterator
     return PyInt_FromLong(n);
 }
 
-DECLARE_RICHCMP(CollationElementIterator, t_collationelementiterator);
+DEFINE_RICHCMP(CollationElementIterator, t_collationelementiterator);
 
 
 void _init_iterators(PyObject *m)
