@@ -25,6 +25,10 @@
 #define _iterators_h
 
 extern PyTypeObject BreakIteratorType;
+extern PyTypeObject CharacterIteratorType;
+extern PyTypeObject CollationElementIteratorType;
+
+PyObject *wrap_CollationElementIterator(CollationElementIterator *, int);
 
 void _init_iterators(PyObject *m);
 
