@@ -62,6 +62,8 @@ static PyObject *t_locale_getDisplayCountry(t_locale *self, PyObject *args);
 static PyObject *t_locale_getDisplayVariant(t_locale *self, PyObject *args);
 static PyObject *t_locale_getDisplayName(t_locale *self, PyObject *args);
 static PyObject *t_locale_createKeywords(t_locale *self);
+static PyObject *t_locale_isBogus(t_locale *self);
+static PyObject *t_locale_setToBogus(t_locale *self);
 static PyObject *t_locale_getEnglish(PyTypeObject *type);
 static PyObject *t_locale_getFrench(PyTypeObject *type);
 static PyObject *t_locale_getGerman(PyTypeObject *type);
@@ -108,6 +110,8 @@ static PyMethodDef t_locale_methods[] = {
     DECLARE_METHOD(t_locale, getDisplayVariant, METH_VARARGS),
     DECLARE_METHOD(t_locale, getDisplayName, METH_VARARGS),
     DECLARE_METHOD(t_locale, createKeywords, METH_NOARGS),
+    DECLARE_METHOD(t_locale, isBogus, METH_NOARGS),
+    DECLARE_METHOD(t_locale, setToBogus, METH_NOARGS),
     DECLARE_METHOD(t_locale, getEnglish, METH_NOARGS | METH_CLASS),
     DECLARE_METHOD(t_locale, getFrench, METH_NOARGS | METH_CLASS),
     DECLARE_METHOD(t_locale, getGerman, METH_NOARGS | METH_CLASS),
@@ -218,7 +222,7 @@ static PyObject *wrap_ResourceBundle(const ResourceBundle &resourcebundle)
 
 static int t_locale_init(t_locale *self, PyObject *args, PyObject *kwds)
 {
-    char *language, *country, *variant;
+    charsArg language, country, variant;
 
     switch (PyTuple_Size(args)) {
       case 0:
@@ -226,7 +230,7 @@ static int t_locale_init(t_locale *self, PyObject *args, PyObject *kwds)
         self->flags = T_OWNED;
         break;
       case 1:
-        if (!parseArgs(args, "c", &language))
+        if (!parseArgs(args, "n", &language))
         {
             self->object = new Locale(language);
             self->flags = T_OWNED;
@@ -235,7 +239,7 @@ static int t_locale_init(t_locale *self, PyObject *args, PyObject *kwds)
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
       case 2:
-        if (!parseArgs(args, "cc", &language, &country))
+        if (!parseArgs(args, "nn", &language, &country))
         {
             self->object = new Locale(language, country);
             self->flags = T_OWNED;
@@ -244,7 +248,7 @@ static int t_locale_init(t_locale *self, PyObject *args, PyObject *kwds)
         PyErr_SetArgsError((PyObject *) self, "__init__", args);
         return -1;
       case 3:
-        if (!parseArgs(args, "ccc", &language, &country, &variant))
+        if (!parseArgs(args, "nnn", &language, &country, &variant))
         {
             self->object = new Locale(language, country, variant);
             self->flags = T_OWNED;
@@ -490,6 +494,18 @@ static PyObject *t_locale_createKeywords(t_locale *self)
     return wrap_StringEnumeration(se, T_OWNED);
 }
 
+static PyObject *t_locale_isBogus(t_locale *self)
+{
+    int retval = self->object->isBogus();
+    Py_RETURN_BOOL(retval);
+}
+
+static PyObject *t_locale_setToBogus(t_locale *self)
+{
+    self->object->setToBogus();
+    Py_RETURN_NONE;
+}
+
 static PyObject *t_locale_getEnglish(PyTypeObject *self)
 {
     return wrap_Locale(Locale::getEnglish());
@@ -623,14 +639,14 @@ static PyObject *t_locale_setDefault(PyTypeObject *type, PyObject *args)
 static PyObject *t_locale_createFromName(PyTypeObject *type, PyObject *args)
 {
     Locale locale;
-    char *name;
+    charsArg name;
 
     switch (PyTuple_Size(args)) {
       case 0:
         locale = Locale::createFromName(NULL);
         return wrap_Locale(locale);
       case 1:
-        if (!parseArgs(args, "c", &name))
+        if (!parseArgs(args, "n", &name))
         {
             locale = Locale::createFromName(name);
             return wrap_Locale(locale);
@@ -644,9 +660,9 @@ static PyObject *t_locale_createFromName(PyTypeObject *type, PyObject *args)
 static PyObject *t_locale_createCanonical(PyTypeObject *type, PyObject *arg)
 {
     Locale locale;
-    char *name;
+    charsArg name;
 
-    if (!parseArg(arg, "c", &name))
+    if (!parseArg(arg, "n", &name))
     {
         locale = Locale::createCanonical(name);
         return wrap_Locale(locale);
@@ -665,7 +681,7 @@ static PyObject *t_locale_getAvailableLocales(PyTypeObject *type)
         Locale *locale = (Locale *) locales + i;
         PyObject *obj = wrap_Locale(locale, 0);
         PyDict_SetItemString(dict, locale->getName(), obj);
-	Py_DECREF(obj);
+        Py_DECREF(obj);
     }
 
     return dict;
@@ -673,9 +689,9 @@ static PyObject *t_locale_getAvailableLocales(PyTypeObject *type)
 
 static PyObject *t_locale_getKeywordValue(t_locale *self, PyObject *arg)
 {
-    char *name;
+    charsArg name;
 
-    if (!parseArg(arg, "c", &name))
+    if (!parseArg(arg, "n", &name))
     {
         char buf[ULOC_FULLNAME_CAPACITY];
         UErrorCode status = U_ZERO_ERROR;
@@ -878,7 +894,7 @@ static PyObject *t_resourcebundle_getNextString(t_resourcebundle *self,
 static PyObject *t_resourcebundle_get(t_resourcebundle *self, PyObject *arg)
 {
     UErrorCode status = U_ZERO_ERROR;
-    char *key;
+    charsArg key;
     int i;
 
     if (!parseArg(arg, "i", &i))
@@ -891,7 +907,7 @@ static PyObject *t_resourcebundle_get(t_resourcebundle *self, PyObject *arg)
         return wrap_ResourceBundle(rb);
     }
 
-    if (!parseArg(arg, "c", &key))
+    if (!parseArg(arg, "n", &key))
     {
         ResourceBundle rb = self->object->get(key, status);
 
@@ -908,9 +924,9 @@ static PyObject *t_resourcebundle_getWithFallback(t_resourcebundle *self,
                                                   PyObject *arg)
 {
     UErrorCode status = U_ZERO_ERROR;
-    char *key;
+    charsArg key;
 
-    if (!parseArg(arg, "c", &key))
+    if (!parseArg(arg, "n", &key))
     {
         ResourceBundle rb = self->object->getWithFallback(key, status);
 
@@ -928,7 +944,7 @@ static PyObject *t_resourcebundle_getStringEx(t_resourcebundle *self,
 {
     UnicodeString *u;
     UnicodeString _u;
-    char *key;
+    charsArg key;
     int i;
 
     switch (PyTuple_Size(args)) {
@@ -938,7 +954,7 @@ static PyObject *t_resourcebundle_getStringEx(t_resourcebundle *self,
             STATUS_CALL(_u = self->object->getStringEx(i, status));
             return PyUnicode_FromUnicodeString(&_u);
         }
-        if (!parseArgs(args, "c", &key))
+        if (!parseArgs(args, "n", &key))
         {
             STATUS_CALL(_u = self->object->getStringEx(key, status));
             return PyUnicode_FromUnicodeString(&_u);
@@ -949,9 +965,9 @@ static PyObject *t_resourcebundle_getStringEx(t_resourcebundle *self,
             STATUS_CALL(u->setTo(self->object->getStringEx(i, status)));
             Py_RETURN_ARG(args, 1);
         }
-        if (!parseArgs(args, "cU", &i, &u))
+        if (!parseArgs(args, "nU", &key, &u))
         {
-            STATUS_CALL(u->setTo(self->object->getStringEx(i, status)));
+            STATUS_CALL(u->setTo(self->object->getStringEx(key, status)));
             Py_RETURN_ARG(args, 1);
         }
         break;
@@ -1017,9 +1033,9 @@ static PyObject *t_resourcebundle_getLocale(t_resourcebundle *self,
 static PyObject *t_resourcebundle_setAppData(PyTypeObject *type,
                                              PyObject *args)
 {
-    char *packageName, *path;
+    charsArg packageName, path;
 
-    if (!parseArgs(args, "cc", &packageName, &path))
+    if (!parseArgs(args, "nf", &packageName, &path))
     {
         HANDLE fd = CreateFile(path, GENERIC_READ, FILE_SHARE_READ,
                                NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, NULL);
@@ -1078,9 +1094,9 @@ static PyObject *t_resourcebundle_setAppData(PyTypeObject *type,
 static PyObject *t_resourcebundle_setAppData(PyTypeObject *type,
                                              PyObject *args)
 {
-    char *packageName, *path;
+    charsArg packageName, path;
 
-    if (!parseArgs(args, "cc", &packageName, &path))
+    if (!parseArgs(args, "nf", &packageName, &path))
     {
         int fd = open(path, O_RDONLY);
         UErrorCode status = U_ZERO_ERROR;
