@@ -162,7 +162,7 @@ static void t_filterednormalizer2_dealloc(t_filterednormalizer2 *self)
 
     Py_CLEAR(self->normalizer);
     Py_CLEAR(self->filter);
-    self->ob_type->tp_free((PyObject *) self);
+    Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
 DECLARE_TYPE(FilteredNormalizer2, t_filterednormalizer2, Normalizer2,
